class PrivateClass(object):
    """A private class with public facing methods."""

    def public_method():
        """This is public."""
        return 5


def imported_function():
    """A function that gets imported."""
    return 1
